from typing import Any
from universal_mcp.applications import APIApplication
from universal_mcp.integrations import Integration

class TestApiApp(APIApplication):
    def __init__(self, integration: Integration = None, **kwargs) -> None:
        super().__init__(name='testapiapp', integration=integration, **kwargs)
        self.base_url = ""

    def test_operation(self, ) -> dict[str, Any]:
        """
        Sends a test GET request to the '/test' endpoint and returns the parsed JSON response.
        
        Args:
            None: This function takes no arguments
        
        Returns:
            A dictionary containing the JSON response from the '/test' endpoint.
        
        Raises:
            requests.HTTPError: If the HTTP request to the '/test' endpoint returns an unsuccessful status code.
        
        Tags:
            test, get, sync, api, important
        """
        url = f"{self.base_url}/test"
        query_params = {}
        response = self._get(url, params=query_params)
        response.raise_for_status()
        return response.json()

    def list_tools(self):
        return [
            self.test_operation
        ]
